@@ -49,46 +49,48 @@ static Layout layouts[] = {
 
 /* you can at most specifiy MAX_ARGS (3) number of arguments */
 static Key keys[] = {
-	{ MOD, 'c',       { create,         { NULL }                    } },
-	{ MOD, 'C',       { create,         { NULL, NULL, "$CWD" }      } },
-	{ MOD, 'x',       { killclient,     { NULL }                    } },
-	{ MOD, 'j',       { focusnext,      { NULL }                    } },
-	{ MOD, 'u',       { focusnextnm,    { NULL }                    } },
-	{ MOD, 'i',       { focusprevnm,    { NULL }                    } },
-	{ MOD, 'k',       { focusprev,      { NULL }                    } },
-	{ MOD, 't',       { setlayout,      { "[]=" }                   } },
-	{ MOD, 'g',       { setlayout,      { "+++" }                   } },
-	{ MOD, 'b',       { setlayout,      { "TTT" }                   } },
-	{ MOD, 'm',       { setlayout,      { "[ ]" }                   } },
-	{ MOD, ' ',       { setlayout,      { NULL }                    } },
-	{ MOD, 'h',       { setmfact,       { "-0.05" }                 } },
-	{ MOD, 'l',       { setmfact,       { "+0.05" }                 } },
-	{ MOD, '.',       { toggleminimize, { NULL }                    } },
-	{ MOD, 's',       { togglebar,      { NULL }                    } },
-	{ MOD, 'M',       { togglemouse,    { NULL }                    } },
-	{ MOD, '\n',      { zoom ,          { NULL }                    } },
-	{ MOD, '1',       { focusn,         { "1" }                     } },
-	{ MOD, '2',       { focusn,         { "2" }                     } },
-	{ MOD, '3',       { focusn,         { "3" }                     } },
-	{ MOD, '4',       { focusn,         { "4" }                     } },
-	{ MOD, '5',       { focusn,         { "5" }                     } },
-	{ MOD, '6',       { focusn,         { "6" }                     } },
-	{ MOD, '7',       { focusn,         { "7" }                     } },
-	{ MOD, '8',       { focusn,         { "8" }                     } },
-	{ MOD, '9',       { focusn,         { "9" }                     } },
-	{ MOD, 'q',       { quit,           { NULL }                    } },
-	{ MOD, 'a',       { togglerunall,   { NULL }                    } },
-	{ MOD, 'r',       { redraw,         { NULL }                    } },
-	{ MOD, 'X',       { lock,           { NULL }                    } },
-	{ MOD, 'B',       { togglebell,     { NULL }                    } },
-	{ MOD, 'v',       { copymode,       { NULL }                    } },
-	{ MOD, '/',       { copymode,       { "/" }                     } },
-	{ MOD, '?',       { copymode,       { "?" }                     } },
-	{ MOD, 'p',       { paste,          { NULL }                    } },
-	{ MOD, KEY_PPAGE, { scrollback,     { "-1" }                    } },
-	{ MOD, KEY_NPAGE, { scrollback,     { "1"  }                    } },
-	{ MOD, KEY_F(1),  { create,         { "man dvtm", "dvtm help" } } },
-	{ MOD, MOD,       { send,           { (const char []){MOD, 0} } } },
+	{ MOD,   'c',           { create,         { NULL }                    } },
+	{ MOD,   'C',           { create,         { NULL, NULL, "$CWD" }      } },
+	{ MOD,   'x',           { killclient,     { NULL }                    } },
+	{ MOD,   'j',           { focusnext,      { NULL }                    } },
+	{ MOD,   'u',           { focusnextnm,    { NULL }                    } },
+	{ MOD,   'i',           { focusprevnm,    { NULL }                    } },
+	{ MOD,   'k',           { focusprev,      { NULL }                    } },
+	{ MOD,   't',           { setlayout,      { "[]=" }                   } },
+	{ MOD,   'g',           { setlayout,      { "+++" }                   } },
+	{ MOD,   'b',           { setlayout,      { "TTT" }                   } },
+	{ MOD,   'm',           { setlayout,      { "[ ]" }                   } },
+	{ MOD,   ' ',           { setlayout,      { NULL }                    } },
+	{ MOD,   'h',           { setmfact,       { "-0.05" }                 } },
+	{ MOD,   'l',           { setmfact,       { "+0.05" }                 } },
+	{ MOD,   '.',           { toggleminimize, { NULL }                    } },
+	{ MOD,   's',           { togglebar,      { NULL }                    } },
+	{ MOD,   'M',           { togglemouse,    { NULL }                    } },
+	{ MOD,   '\n',          { zoom ,          { NULL }                    } },
+	{ MOD,   '1',           { focusn,         { "1" }                     } },
+	{ MOD,   '2',           { focusn,         { "2" }                     } },
+	{ MOD,   '3',           { focusn,         { "3" }                     } },
+	{ MOD,   '4',           { focusn,         { "4" }                     } },
+	{ MOD,   '5',           { focusn,         { "5" }                     } },
+	{ MOD,   '6',           { focusn,         { "6" }                     } },
+	{ MOD,   '7',           { focusn,         { "7" }                     } },
+	{ MOD,   '8',           { focusn,         { "8" }                     } },
+	{ MOD,   '9',           { focusn,         { "9" }                     } },
+	{ MOD,   '\t',          { focuslast,      { NULL }                    } },
+	{ MOD,   'q',           { quit,           { NULL }                    } },
+	{ MOD,   'a',           { togglerunall,   { NULL }                    } },
+	{ MOD,   'r',           { redraw,         { NULL }                    } },
+	{ MOD,   'B',           { togglebell,     { NULL }                    } },
+	{ MOD,   'v',           { copymode,       { NULL }                    } },
+	{ MOD,   '/',           { copymode,       { "/" }                     } },
+	{ MOD,   '?',           { copymode,       { "?" }                     } },
+	{ MOD,   'p',           { paste,          { NULL }                    } },
+	{ MOD,   KEY_PPAGE,     { scrollback,     { "-1" }                    } },
+	{ MOD,   KEY_NPAGE,     { scrollback,     { "1"  }                    } },
+	{ MOD,   KEY_F(1),      { create,         { "man dvtm", "dvtm help" } } },
+	{ MOD,   MOD,           { send,           { (const char []){MOD, 0} } } },
+	{ NOMOD, KEY_SPREVIOUS, { scrollback,     { "-1" }                    } },
+	{ NOMOD, KEY_SNEXT,     { scrollback,     { "1"  }                    } },
 };
 
 static const ColorRule colorrules[] = {
