@@ -72,6 +72,10 @@
 # define MAX_COLOR_PAIRS COLOR_PAIRS
 #endif
 
+#ifndef CTRL
+# define CTRL(k)   ((k) & 0x1F)
+#endif
+
 #define IS_CONTROL(ch) !((ch) & 0xffffff60UL)
 #define MIN(x, y) ((x) < (y) ? (x) : (y))
 #define sstrlen(str) (sizeof(str) - 1)
@@ -163,6 +167,8 @@ struct Vt {
 	char rbuf[BUFSIZ];
 	char ebuf[BUFSIZ];
 	unsigned int rlen, elen;
+	/* last known start row, start column */
+	int srow, scol;
 
 	/* xterm style window title */
 	char title[256];
@@ -1457,6 +1463,12 @@ void vt_draw(Vt *t, WINDOW * win, int srow, int scol)
 	Row *sel_row_start, *sel_row_end;
 	int sel_col_start, sel_col_end;
 
+	if (srow != t->srow || scol != t->scol) {
+		vt_dirty(t);
+		t->srow = srow;
+		t->scol = scol;
+	}
+
 	copymode_get_selection_boundry(t, &sel_row_start, &sel_col_start, &sel_row_end, &sel_col_end, true);
 
 	for (int i = 0; i < b->rows; i++) {
@@ -1927,7 +1939,7 @@ static void cmdline_keypress(Cmdline *c, int keycode)
 		c->display = disp >= c->buf ? disp + 1: c->buf;
 		c->cursor_pos = (width < c->width - 1) ? width : c->width - 1;
 		break;
-	case 1 ... 26: /* CTRL('a') ... CTRL('z') */
+	case CTRL('a') ... CTRL('z'):
 		if (keycode != '\n')
 			break;
 		copymode_search(c->data, c->prefix == '/' ? 1 : -1);
@@ -2006,10 +2018,17 @@ void vt_copymode_keypress(Vt *t, int keycode)
 		cmdline_keypress(t->cmdline, keycode);
 	} else {
 		switch (keycode) {
-		case '0' ... '9':
+		case '0':
+			if (t->copymode_cmd_multiplier == 0) {
+				b->curs_col = 0;
+				break;
+			}
+			/* fall through */
+		case '1' ... '9':
 			t->copymode_cmd_multiplier = (t->copymode_cmd_multiplier * 10) + (keychar - '0');
 			return;
 		case KEY_PPAGE:
+		case CTRL('u'):
 			delta = b->curs_row - b->lines;
 			if (delta > scroll_page)
 				b->curs_row -= scroll_page;
@@ -2019,6 +2038,7 @@ void vt_copymode_keypress(Vt *t, int keycode)
 			}
 			break;
 		case KEY_NPAGE:
+		case CTRL('d'):
 			delta = b->rows - (b->curs_row - b->lines);
 			if (delta > scroll_page)
 				b->curs_row += scroll_page;
@@ -2124,6 +2144,7 @@ void vt_copymode_keypress(Vt *t, int keycode)
 			/* fall through */
 		case '\e':
 		case 'q':
+		case CTRL('c'):
 			vt_copymode_leave(t);
 			return;
 		default:
