@@ -1,7 +1,7 @@
 /*
  * Copyright © 2004 Bruno T. C. de Oliveira
  * Copyright © 2006 Pierre Habouzit
- * Copyright © 2008-2012 Marc Andre Tanner
+ * Copyright © 2008-2013 Marc André Tanner
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -55,11 +55,14 @@ typedef int (*vt_escseq_handler_t)(Vt *, char *es);
 
 enum {
 	VT_EVENT_TITLE,
+	VT_EVENT_COPY_TEXT,
 };
 
 typedef void (*vt_event_handler_t)(Vt *, int event, void *data);
 
 void vt_init(void);
+void vt_set_keytable(char const * const keytable_overlay[], int count);
+void vt_shutdown(void);
 void vt_set_escseq_handler(Vt *, vt_escseq_handler_t);
 void vt_set_event_handler(Vt *, vt_event_handler_t);
 void vt_set_data(Vt *, void *);
@@ -69,7 +72,7 @@ void vt_set_default_colors(Vt *, unsigned attrs, short fg, short bg);
 Vt *vt_create(int rows, int cols, int scroll_buf_sz);
 void vt_resize(Vt *, int rows, int cols);
 void vt_destroy(Vt *);
-pid_t vt_forkpty(Vt *, const char *, const char *argv[], const char *envp[], int *pty);
+pid_t vt_forkpty(Vt *, const char *, const char *argv[], const char *cwd, const char *envp[], int *pty);
 int vt_getpty(Vt *);
 unsigned vt_cursor(Vt *t);
 
@@ -79,7 +82,8 @@ int vt_write(Vt *t, const char *buf, int len);
 void vt_mouse(Vt *t, int x, int y, mmask_t mask);
 void vt_dirty(Vt *t);
 void vt_draw(Vt *, WINDOW *win, int startrow, int startcol);
-short vt_color_get(short fg, short bg);
+short vt_color_get(Vt *t, short fg, short bg);
+short vt_color_reserve(short fg, short bg);
 
 void vt_scroll(Vt *, int rows);
 void vt_noscroll(Vt *);
@@ -87,4 +91,9 @@ void vt_noscroll(Vt *);
 void vt_bell(Vt *, bool bell);
 void vt_togglebell(Vt *);
 
+void vt_copymode_enter(Vt *t);
+void vt_copymode_leave(Vt *t);
+unsigned vt_copymode(Vt *t);
+void vt_copymode_keypress(Vt *t, int keycode);
+
 #endif /* VT_VT_H */
